@@ -1,13 +1,12 @@
 package App::GitGot;
-$App::GitGot::VERSION = '1.22';
-use Mouse;
-use strict;
-use warnings;
-extends 'MouseX::App::Cmd';
+$App::GitGot::VERSION = '1.24';
 # ABSTRACT: A tool to make it easier to manage multiple git repositories.
+use 5.014;
+use warnings;
+
+use App::Cmd::Setup -app;
 
 
-__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -22,7 +21,7 @@ App::GitGot - A tool to make it easier to manage multiple git repositories.
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 SYNOPSIS
 
@@ -34,7 +33,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
