@@ -1,11 +1,12 @@
 package App::GitGot::Command::chdir;
-$App::GitGot::Command::chdir::VERSION = '1.22';
+$App::GitGot::Command::chdir::VERSION = '1.24';
 # ABSTRACT: open a subshell in a selected project
-use Mouse;
+use 5.014;
+
+use App::GitGot -command;
+
+use Moo;
 extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
 use namespace::autoclean;
 
 sub command_names { qw/ chdir cd / }
@@ -26,9 +27,10 @@ sub _execute {
   exec $ENV{SHELL};
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+### FIXME docs
+
 __END__
 
 =pod
@@ -41,7 +43,7 @@ App::GitGot::Command::chdir - open a subshell in a selected project
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -49,7 +51,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
