@@ -1,28 +1,30 @@
 package App::GitGot::Command::clone;
-$App::GitGot::Command::clone::VERSION = '1.22';
+$App::GitGot::Command::clone::VERSION = '1.24';
 # ABSTRACT: clone a remote repo and add it to your config
-use Mouse;
+use 5.014;
+
+use Cwd;
+use Path::Tiny;
+use IO::Prompt::Simple;
+use Types::Standard -types;
+
+use App::GitGot -command;
+use App::GitGot::Repo::Git;
+
+use Moo;
 extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
 use namespace::autoclean;
 
-use App::GitGot::Repo::Git;
-use Cwd;
-use File::Basename;
-use File::Spec;
-use Term::ReadLine;
-
-has defaults => (
-  is          => 'rw',
-  isa         => 'Bool',
-  cmd_aliases => 'D',
-  traits      => [qw/ Getopt /],
-);
+sub options {
+  my( $class , $app ) = @_;
+  return (
+    [ 'defaults|D' => 'FIXME' ] ,
+  );
+}
 
 sub _execute {
   my ( $self, $opt, $args ) = @_;
+
   my ( $repo , $path ) = @$args;
 
   $repo // ( say STDERR 'ERROR: Need the URL to clone!' and exit(1) );
@@ -30,20 +32,18 @@ sub _execute {
   my $cwd = getcwd
     or( say STDERR "ERROR: Couldn't determine path" and exit(1) );
 
-
-  my $name = basename $repo;
+  my $name = path( $repo )->basename;
   $name =~ s/.git$//;
 
   $path //= "$cwd/$name";
-  $path = File::Spec->rel2abs( $path );
+  $path = path( $path )->absolute;
 
   my $tags;
 
-  unless ( $self->defaults ) {
-    my $term = Term::ReadLine->new('gitgot');
-    $name = $term->readline( 'Name: ', $name );
-    $path = $term->readline( 'Path: ', $path );
-    $tags = $term->readline( 'Tags: ', $tags );
+  unless ( $self->opt->defaults ) {
+    $name = prompt( 'Name: ' , $name );
+    $path = prompt( 'Path: ' , $path );
+    $tags = prompt( 'Tags: ' , $tags );
   }
 
   my $new_entry = App::GitGot::Repo::Git->new({ entry => {
@@ -60,9 +60,10 @@ sub _execute {
   $self->write_config;
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+### FIXME docs
+
 __END__
 
 =pod
@@ -75,7 +76,7 @@ App::GitGot::Command::clone - clone a remote repo and add it to your config
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -83,7 +84,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
