@@ -1,40 +1,31 @@
 package App::GitGot::Command::do;
-$App::GitGot::Command::do::VERSION = '1.22';
+$App::GitGot::Command::do::VERSION = '1.24';
 # ABSTRACT: run command in many repositories
-use Mouse;
-extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
-use namespace::autoclean;
+use 5.014;
 
 use Capture::Tiny qw/ capture_stdout /;
 use File::chdir;
+use Types::Standard -types;
 
-has command => (
-  is            => 'ro',
-  isa           => 'Str',
-  required      => 1,
-  traits        => [qw/ Getopt /],
-  documentation => 'command to execute in the different repos',
-  cmd_aliases   => 'e',
-);
+use App::GitGot -command;
 
-has with_repo => (
-  is            => 'ro',
-  isa           => 'Bool',
-  default       => 0,
-  traits        => [qw/ Getopt /],
-  documentation => 'prepend all output lines with the repo name',
-);
+use Moo;
+extends 'App::GitGot::Command';
+use namespace::autoclean;
 
-sub command_names { qw/ do / }
+sub options {
+  my( $class , $app ) = @_;
+  return (
+    [ 'command|e=s' => 'command to execute in the different repos' => { required => 1 } ] ,
+    [ 'with_repo'   => 'prepend all output lines with the repo name' => { default => 0 } ] ,
+  );
+}
 
 sub _execute {
   my $self = shift;
 
   for my $repo ( $self->active_repos ) {
-    $self->_run_in_repo( $repo => $self->command );
+    $self->_run_in_repo( $repo => $self->opt->command );
   }
 }
 
@@ -47,9 +38,9 @@ sub _run_in_repo {
     return;
   }
 
-  say "\n## repo ", $repo->label, "\n" unless $self->with_repo;
+  say "\n## repo ", $repo->label, "\n" unless $self->opt->with_repo;
 
-  my $prefix = $self->with_repo ? $repo->label . ': ' : '';
+  my $prefix = $self->opt->with_repo ? $repo->label . ': ' : '';
 
   say $prefix, $_ for split "\n", capture_stdout {
     $CWD = $repo->path;
@@ -57,9 +48,10 @@ sub _run_in_repo {
   };
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+### FIXME docs
+
 __END__
 
 =pod
@@ -72,7 +64,7 @@ App::GitGot::Command::do - run command in many repositories
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -80,7 +72,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
