@@ -1,14 +1,13 @@
 package App::GitGot::Command::fetch;
-$App::GitGot::Command::fetch::VERSION = '1.22';
+$App::GitGot::Command::fetch::VERSION = '1.24';
 # ABSTRACT: fetch remotes for managed repositories
-use Mouse;
-extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
-use namespace::autoclean;
+use 5.014;
 
-sub command_names { qw/ fetch / }
+use App::GitGot -command;
+
+use Moo;
+extends 'App::GitGot::Command';
+use namespace::autoclean;
 
 sub _execute {
   my ( $self, $opt, $args ) = @_;
@@ -16,9 +15,10 @@ sub _execute {
   $self->_fetch( $self->active_repos );
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+### FIXME docs
+
 __END__
 
 =pod
@@ -31,7 +31,7 @@ App::GitGot::Command::fetch - fetch remotes for managed repositories
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -39,7 +39,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
