@@ -1,16 +1,15 @@
 package App::GitGot::Command::gc;
-$App::GitGot::Command::gc::VERSION = '1.22';
+$App::GitGot::Command::gc::VERSION = '1.24';
 # ABSTRACT: Run the 'gc' command to garbage collect in git repos
-use Mouse;
-extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
-use namespace::autoclean;
+use 5.014;
 
 use Data::Dumper;
 use Try::Tiny;
 
+use Moo;
+extends 'App::GitGot::Command';
+use namespace::autoclean;
+
 # incremental output looks nicer for this command...
 STDOUT->autoflush(1);
 sub _use_io_page { 0 }
@@ -35,9 +34,10 @@ sub _execute {
   }
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+## FIXME docs
+
 __END__
 
 =pod
@@ -50,7 +50,7 @@ App::GitGot::Command::gc - Run the 'gc' command to garbage collect in git repos
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -58,7 +58,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
