@@ -1,29 +1,29 @@
 package App::GitGot::Command::list;
-$App::GitGot::Command::list::VERSION = '1.22';
+$App::GitGot::Command::list::VERSION = '1.24';
 # ABSTRACT: list managed repositories
-use Mouse;
-extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
-use namespace::autoclean;
+use 5.014;
 
 use Class::Load       'try_load_class';
 
+use App::GitGot -command;
+
+use Moo;
+extends 'App::GitGot::Command';
+use namespace::autoclean;
+
 sub command_names { qw/ list ls / }
 
-has json => (
-  is            => 'ro',
-  isa           => 'Bool',
-  cmd_aliases   => 'j',
-  traits        => [qw/ Getopt /],
-  documentation => 'stream output as json',
-);
+sub options {
+  my( $class , $app ) = @_;
+  return (
+    [ 'json|j' => 'stream output as JSON' ] ,
+  );
+}
 
 sub _execute {
   my( $self, $opt, $args ) = @_;
 
-  if ( $self->json ) {
+  if ( $self->opt->json ) {
     try_load_class( 'JSON' )
       or die "json serializing requires the module 'JSON' to be installed\n";
 
@@ -54,9 +54,10 @@ sub _execute {
   }
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+## FIXME docs
+
 __END__
 
 =pod
@@ -69,7 +70,7 @@ App::GitGot::Command::list - list managed repositories
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -77,7 +78,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
