@@ -1,37 +1,40 @@
 package App::GitGot::Command::move;
-$App::GitGot::Command::move::VERSION = '1.22';
-# ABSTRACT: move a repo in a new directory
-use Mouse;
-extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
-use namespace::autoclean;
+$App::GitGot::Command::move::VERSION = '1.24';
+# ABSTRACT: move repo to new location
+use 5.014;
 
 use Cwd;
 use File::Copy::Recursive qw/ dirmove /;
-use Path::Class;
+use Path::Tiny;
+
+use App::GitGot -command;
+
+use Moo;
+extends 'App::GitGot::Command';
+use namespace::autoclean;
 
 sub command_names { qw/ move mv / }
 
-has destination => (
-  is          => 'ro',
-  isa         => 'Str',
-  required    => 1,
-  traits      => [qw/ Getopt /],
-);
+sub options {
+  my( $class , $app ) = @_;
+  return (
+    [ 'destination=s' => 'FIXME' => { required => 1 } ] ,
+  );
+}
 
 sub _execute {
   my( $self, $opt, $args ) = @_;
 
   my @repos = $self->active_repos;
 
-  dir($self->destination)->mkpath if @repos > 1;
+  my $dest = $self->opt->destination;
+
+  path($dest)->mkpath if @repos > 1;
 
   for my $repo ( @repos ) {
-    my $target_dir = -d $self->destination
-      ? dir($self->destination)->subdir( dir($repo->path)->basename )
-      : $self->destination;
+    my $target_dir = -d $dest
+      ? path($dest)->child( path($repo->path)->basename )
+      : $dest;
 
     dirmove( $repo->path => $target_dir )
       or die "couldn't move ", $repo->name, " to '$target_dir': $!";
@@ -41,12 +44,12 @@ sub _execute {
 
     say sprintf '%s moved to %s', $repo->name, $target_dir;
   }
-
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+## FIXME docs
+
 __END__
 
 =pod
@@ -55,11 +58,11 @@ __END__
 
 =head1 NAME
 
-App::GitGot::Command::move - move a repo in a new directory
+App::GitGot::Command::move - move repo to new location
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -67,7 +70,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
