@@ -1,37 +1,30 @@
 package App::GitGot::Command::mux;
-$App::GitGot::Command::mux::VERSION = '1.22';
+$App::GitGot::Command::mux::VERSION = '1.24';
 # ABSTRACT: open a tmux window for a selected project
-use Mouse;
+use 5.014;
+
+use App::GitGot -command;
+
+use Moo;
 extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
 use namespace::autoclean;
 
-has dirty => (
-  traits        => [qw(Getopt)] ,
-  isa           => 'Bool',
-  is            => 'ro',
-  cmd_aliases   => 'D',
-  documentation => 'open session or window for all dirty repos'
-);
-
-has session => (
-  traits        => [qw(Getopt)],
-  isa           => 'Bool',
-  is            => 'ro',
-  cmd_aliases   => 's',
-  documentation => 'use tmux-sessions',
-);
-
 sub command_names { qw/ mux tmux / }
 
+sub options {
+  my( $class , $app ) = @_;
+  return (
+    [ 'dirty|D'   => 'open session or window for all dirty repos' ] ,
+    [ 'session|s' => 'use tmux-sessions (default: tmux windows)' ] ,
+  );
+}
+
 sub _execute {
   my( $self, $opt, $args ) = @_;
 
-  my @repos = $self->dirty ? $self->_get_dirty_repos() : $self->active_repos();
+  my @repos = $self->opt->dirty ? $self->_get_dirty_repos() : $self->active_repos();
 
-  my $target = $self->session ? 'session' : 'window';
+  my $target = $self->opt->session ? 'session' : 'window';
 
  REPO: foreach my $repo ( @repos ) {
     # is it already opened?
@@ -39,7 +32,7 @@ sub _execute {
       split "\n", `tmux list-$target -F"#I:::#W"`;
 
     if( my $window = $windows{$repo->name} ) {
-      if ($self->session) {
+      if ($self->opt->session) {
         system 'tmux', 'switch-client', '-t' => $window;
       }
       else {
@@ -50,7 +43,7 @@ sub _execute {
 
     chdir $repo->path;
 
-    if ($self->session) {
+    if ($self->opt->session) {
       delete local $ENV{TMUX};
       system 'tmux', 'new-session', '-d', '-s', $repo->name;
       system 'tmux', 'switch-client', '-t' => $repo->name;}
@@ -78,9 +71,10 @@ sub _get_dirty_repos {
   return @dirty_repos;
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+## FIXME docs
+
 __END__
 
 =pod
@@ -93,7 +87,7 @@ App::GitGot::Command::mux - open a tmux window for a selected project
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -101,7 +95,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
