@@ -1,16 +1,17 @@
 package App::GitGot::Command::push;
-$App::GitGot::Command::push::VERSION = '1.22';
+$App::GitGot::Command::push::VERSION = '1.24';
 # ABSTRACT: Push local changes to the default remote in git repos
-use Mouse;
-extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
-use namespace::autoclean;
+use 5.014;
 
 use Data::Dumper;
 use Try::Tiny;
 
+use App::GitGot -command;
+
+use Moo;
+extends 'App::GitGot::Command';
+use namespace::autoclean;
+
 # incremental output looks nicer for this command...
 STDOUT->autoflush(1);
 sub _use_io_page { 0 }
@@ -42,9 +43,10 @@ sub _execute {
   }
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+## FIXME docs
+
 __END__
 
 =pod
@@ -57,7 +59,7 @@ App::GitGot::Command::push - Push local changes to the default remote in git rep
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -65,7 +67,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
