@@ -1,23 +1,27 @@
 package App::GitGot::Command::remove;
-$App::GitGot::Command::remove::VERSION = '1.22';
+$App::GitGot::Command::remove::VERSION = '1.24';
 # ABSTRACT: remove a managed repository from your config
-use Mouse;
+use 5.014;
+
+use List::AllUtils qw/ any /;
+
+use App::GitGot -command;
+
+use Moo;
 extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
 use namespace::autoclean;
 
-use List::MoreUtils qw/ any /;
-
-has force => (
-  is     => 'rw',
-  isa    => 'Bool',
-  traits => [qw/ Getopt /],
-);
-
 sub command_names { qw/ remove rm / }
 
+sub options {
+  my( $class , $app ) = @_;
+  return (
+    [ 'force' => 'FIXME' ] ,
+  );
+}
+
+sub _use_io_page { 0 }
+
 sub _execute {
   my( $self, $opt, $args ) = @_;
 
@@ -34,7 +38,7 @@ sub _execute {
     if ( any { $number == $_->number } $self->active_repos ) {
       my $name = $repo->label;
 
-      if ( $self->force or $self->prompt_yn( "got rm: remove '$name'?" )) {
+      if ( $self->opt->force or $self->prompt_yn( "got rm: remove '$name'?" )) {
         say "Removed repo '$name'" if $self->verbose;
         next REPO;
       }
@@ -42,13 +46,14 @@ sub _execute {
     push @new_repo_list , $repo;
   }
 
-  $self->full_repo_list( \@new_repo_list );
+  $self->set_full_repo_list( \@new_repo_list );
   $self->write_config();
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+## FIXME docs
+
 __END__
 
 =pod
@@ -61,7 +66,7 @@ App::GitGot::Command::remove - remove a managed repository from your config
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -69,7 +74,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
