@@ -1,14 +1,11 @@
 package App::GitGot::Command::that;
-$App::GitGot::Command::that::VERSION = '1.22';
+$App::GitGot::Command::that::VERSION = '1.24';
 # ABSTRACT: check if a given repository is managed
-use Mouse;
-extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
-use namespace::autoclean;
+use 5.014;
 
-sub command_names { qw/ that / }
+use Moo;
+extends 'App::GitGot::Command';
+use namespace::autoclean;
 
 sub _execute {
   my( $self, $opt, $args ) = @_;
@@ -20,9 +17,10 @@ sub _execute {
   $self->_path_is_managed( $path ) or exit 1;
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+## FIXME docs
+
 __END__
 
 =pod
@@ -35,7 +33,7 @@ App::GitGot::Command::that - check if a given repository is managed
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -43,7 +41,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
