@@ -1,16 +1,13 @@
 package App::GitGot::Command::this;
-$App::GitGot::Command::this::VERSION = '1.22';
+$App::GitGot::Command::this::VERSION = '1.24';
 # ABSTRACT: check if the current repository is managed
-use Mouse;
-extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
-use namespace::autoclean;
+use 5.014;
 
 use Cwd;
 
-sub command_names { qw/ this / }
+use Moo;
+extends 'App::GitGot::Command';
+use namespace::autoclean;
 
 sub _execute {
   my( $self, $opt, $args ) = @_;
@@ -18,9 +15,10 @@ sub _execute {
   $self->_path_is_managed( getcwd() ) or exit 1;
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+## FIXME docs
+
 __END__
 
 =pod
@@ -33,7 +31,7 @@ App::GitGot::Command::this - check if the current repository is managed
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -41,7 +39,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
