@@ -1,11 +1,10 @@
 package App::GitGot::Command::update_status;
-$App::GitGot::Command::update_status::VERSION = '1.22';
+$App::GitGot::Command::update_status::VERSION = '1.24';
 # ABSTRACT: update managed repositories then display their status
-use Mouse;
+use 5.014;
+
+use Moo;
 extends 'App::GitGot::Command';
-use strict;
-use warnings;
-use 5.010;
 use namespace::autoclean;
 
 sub command_names { qw/ update_status upst / }
@@ -20,9 +19,10 @@ sub _execute {
   $self->_status( $self->active_repos );
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
+## FIXME docs
+
 __END__
 
 =pod
@@ -35,7 +35,7 @@ App::GitGot::Command::update_status - update managed repositories then display t
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 AUTHOR
 
@@ -43,7 +43,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
