@@ -1,19 +1,22 @@
 package App::GitGot::Outputter;
-$App::GitGot::Outputter::VERSION = '1.22';
+$App::GitGot::Outputter::VERSION = '1.24';
 # ABSTRACT: Generic base class for outputting formatted messages.
-use Mouse;
-use strict;
-use warnings;
-use 5.010;
+use 5.014;
+
+use Term::ANSIColor qw/ colored /;
+use Types::Standard -types;
+
+use App::GitGot::Types;
+
+use Moo;
 use namespace::autoclean;
 
-use Term::ANSIColor;
 
-# boolean indicating whether color messages should be output at all
 has no_color => (
-  is      => 'ro' ,
-  isa     => 'Bool' ,
-  default => 0 ,
+  is            => 'ro' ,
+  isa           => Bool ,
+  default       => 0 ,
+  documentation => 'boolean indicating whether color messages should be output at all' ,
 );
 
 
@@ -47,7 +50,6 @@ sub _colored {
     : colored( $message , $color_string );
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -62,7 +64,13 @@ App::GitGot::Outputter - Generic base class for outputting formatted messages.
 
 =head1 VERSION
 
-version 1.22
+version 1.24
+
+=head1 ATTRIBUTES
+
+=head2 no_color
+
+Boolean indicating whether color messages should be output at all.
 
 =head1 METHODS
 
@@ -88,7 +96,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
