@@ -1,16 +1,19 @@
 package App::GitGot::Outputter::light;
-$App::GitGot::Outputter::light::VERSION = '1.22';
+$App::GitGot::Outputter::light::VERSION = '1.24';
 # ABSTRACT: Color scheme appropriate for dark terminal backgrounds
-use Mouse;
+use 5.014;
+
+use Types::Standard -types;
+
+use App::GitGot::Types;
+
+use Moo;
 extends 'App::GitGot::Outputter';
-use strict;
-use warnings;
-use 5.010;
 use namespace::autoclean;
 
 has color_error => (
   is      => 'ro' ,
-  isa     => 'Str' ,
+  isa     => Str ,
   default => 'bold red'
 );
 
@@ -19,23 +22,23 @@ has color_error => (
 
 has color_major_change => (
   is      => 'ro' ,
-  isa     => 'Str' ,
+  isa     => Str ,
   default => 'blue'
 );
 
 has color_minor_change => (
   is      => 'ro' ,
-  isa     => 'Str' ,
+  isa     => Str ,
   default => 'uncolored'
 );
 
 has color_warning => (
   is      => 'ro' ,
-  isa     => 'Str' ,
+  isa     => Str ,
   default => 'bold magenta'
 );
 
-__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -50,7 +53,9 @@ App::GitGot::Outputter::light - Color scheme appropriate for dark terminal backg
 
 =head1 VERSION
 
-version 1.22
+version 1.24
+
+=for Pod::Coverage color_error color_major_change color_minor_change color_warning
 
 =head1 AUTHOR
 
@@ -58,7 +63,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
