@@ -1,51 +1,61 @@
 package App::GitGot::Repo;
-$App::GitGot::Repo::VERSION = '1.22';
+$App::GitGot::Repo::VERSION = '1.24';
 # ABSTRACT: Base repository objects
-use Mouse;
-use strict;
-use warnings;
-use 5.010;
-use namespace::autoclean;
+use 5.014;
 
 use List::AllUtils qw/ uniq /;
+use Types::Standard -types;
+
+use App::GitGot::Types;
+
+use Moo;
+use namespace::autoclean;
+
 
 has label => (
-  is       => 'ro' ,
-  isa      => 'Str' ,
+  is  => 'ro' ,
+  isa => Str ,
 );
 
+
 has name => (
-  is          => 'ro',
-  isa         => 'Str',
-  required    => 1 ,
+  is       => 'ro',
+  isa      => Str,
+  required => 1 ,
 );
 
+
 has number => (
-  is          => 'ro',
-  isa         => 'Int',
-  required    => 1 ,
+  is       => 'ro',
+  isa      => Int,
+  required => 1 ,
 );
 
+
 has path => (
-  is          => 'ro',
-  isa         => 'Str',
-  required    => 1 ,
+  is       => 'ro',
+  isa      => Str,
+  required => 1 ,
+  coerce   => sub { $_[0]->isa('Path::Tiny') ? "$_[0]" : $_[0] } ,
 );
 
+
 has repo => (
-  is          => 'ro',
-  isa         => 'Str',
+  is  => 'ro',
+  isa => Str,
 );
 
+
 has tags => (
-  is          => 'rw',
-  isa         => 'Str',
+  is  => 'rw',
+  isa => Str,
 );
 
+
 has type => (
-  is          => 'ro',
-  isa         => 'Str',
-  required    => 1 ,
+  is       => 'ro',
+  isa      => Str,
+  required => 1 ,
 );
 
 sub BUILDARGS {
@@ -59,6 +69,7 @@ sub BUILDARGS {
   my $repo = $entry->{repo} //= '';
 
   if ( ! defined $entry->{name} ) {
+    ### FIXME this is unnecessarily Git-specific
     $entry->{name} = ( $repo =~ m|([^/]+).git$| ) ? $1 : '';
   }
 
@@ -110,7 +121,7 @@ sub remove_tags {
   $self->tags( join ' ', grep { !$verboten{$_} } split ' ', $self->tags );
 }
 
-__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -125,7 +136,35 @@ App::GitGot::Repo - Base repository objects
 
 =head1 VERSION
 
-version 1.22
+version 1.24
+
+=head1 ATTRIBUTES
+
+=head2 label
+
+Optional label for the repo.
+
+=head2 name
+
+The name of the repo.
+
+=head2 number
+
+The number of the repo.
+
+=head2 path
+
+The path to the repo.
+
+=head2 repo
+
+=head2 tags
+
+Space-separated list of tags for the repo
+
+=head2 type
+
+The type of the repo (git, svn, etc.).
 
 =head1 METHODS
 
@@ -144,13 +183,15 @@ Given a list of tags, remove them from the current repo object.
 
 Passing a tag that is not on the current repo object will silently no-op.
 
+=for Pod::Coverage BUILDARGS
+
 =head1 AUTHOR
 
 John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
