@@ -1,23 +1,24 @@
 package App::GitGot::Repo::Git;
-$App::GitGot::Repo::Git::VERSION = '1.22';
+$App::GitGot::Repo::Git::VERSION = '1.24';
 # ABSTRACT: Git repo objects
-use Mouse;
-extends 'App::GitGot::Repo';
-use strict;
-use warnings;
-use 5.010;
-use namespace::autoclean;
+use 5.014;
 
 use Git::Wrapper;
 use Test::MockObject;
 use Try::Tiny;
+use Types::Standard -types;
+
+use App::GitGot::Types qw/ GitWrapper /;
+
+use Moo;
+extends 'App::GitGot::Repo';
+use namespace::autoclean;
 
 has '+type' => ( default => 'git' );
 
 has '_wrapper' => (
-  is         => 'ro' ,
-  isa        => 'Git::Wrapper' ,
-  lazy_build => 1 ,
+  is         => 'lazy' ,
+  isa        => GitWrapper ,
   handles    => [ qw/
                       cherry
                       clone
@@ -57,6 +58,7 @@ sub _build__wrapper {
 }
 
 
+
 sub current_branch {
   my $self = shift;
 
@@ -74,6 +76,7 @@ sub current_branch {
   return $branch;
 }
 
+
 sub current_remote_branch {
   my( $self ) = shift;
 
@@ -92,7 +95,6 @@ sub current_remote_branch {
   return $remote;
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -107,7 +109,7 @@ App::GitGot::Repo::Git - Git repo objects
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 METHODS
 
@@ -127,7 +129,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
