@@ -1,21 +1,28 @@
 package App::GitGot::Repositories;
-$App::GitGot::Repositories::VERSION = '1.22';
+$App::GitGot::Repositories::VERSION = '1.24';
 # ABSTRACT: Object holding a collection of repositories
-use Mouse;
-use strict;
-use warnings;
-use 5.010;
+use 5.014;
+
+use Types::Standard -types;
+
+use App::GitGot::Types qw/ GotRepo /;
+
+use Moo;
+use MooX::HandlesVia;
 use namespace::autoclean;
 
 use overload '@{}' => sub { $_[0]->all };
 
+
 has repos => (
-  is       => 'ro',
-  isa      => 'ArrayRef[App::GitGot::Repo::Git]',
-  traits   => [ qw/ Array / ],
-  default  => sub { [] },
-  required => 1,
-  handles  => { all => 'elements' },
+  is          => 'ro',
+  isa         => ArrayRef[GotRepo],
+  default     => sub { [] },
+  required    => 1,
+  handles_via => 'Array' ,
+  handles     => {
+    all => 'elements'
+  }
 );
 
 
@@ -40,7 +47,6 @@ sub tags {
   return App::GitGot::Repositories->new( repos => \@repos );
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -55,7 +61,13 @@ App::GitGot::Repositories - Object holding a collection of repositories
 
 =head1 VERSION
 
-version 1.22
+version 1.24
+
+=head1 ATTRIBUTES
+
+=head2 repos
+
+Array of the C<App::GitGot::Repo> objects in the collection.
 
 =head1 METHODS
 
@@ -76,7 +88,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
